/* $Workfile: OtxBrdD.h $   $Revision: 52 $    $Modtime: 10/19/07 6:49p $  */
#ifndef OTX_BRD_DEF_H
#define OTX_BRD_DEF_H
/******************************************************************************

  @doc PublicHwApi OtxBrdD

  Copyright (C) 1998-2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBrdD | Constants, Macros, and Types for the Board Level Functions

  @contents2
  OtxBrdD.h |

  @index enum struct type | OtxBrdD

  @contents2
  OTX Board Level Constants, Macros, and Types |

  @head3 OtxBrdXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxBrdD

******************************************************************************/

#ifdef __cplusplus
extern "C" {
#endif

#include "OtxErr.h"
#include "OtxType.h"


/******************************************************************************
  @enum 
    Board Device Attributes
******************************************************************************/
enum OtxBoardDeviceAttributesE {
  OTX_ATTR_BRD_SERIAL_NUMBER            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_SZ) Read only. Serial Number of the board (ALL boards)
  OTX_ATTR_BRD_BUILD                    = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_SZ) Read only. Board population build (ALL boards)
  OTX_ATTR_BRD_CIS_REV                  = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_SZ) Read only. CIS Revision Number (PCMCIA boards)
  OTX_ATTR_BRD_CPLD_BUILD               = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_SZ) Read only. FUTURE USE: CPLD Build (PCI boards)
  OTX_ATTR_BRD_BUS_ADDRESS              = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read only. WDM driver only. Bus specific location address for the board
  OTX_ATTR_BRD_PCMCIA_SOCKET_NUMBER     = OTX_ATTR_END + 5,  // @emem (OTX_ATTRIB_UINT32) Read only. PCMCIA Socket number (0,1). (PCMCIA boards)
  OTX_ATTR_BRD_PCI_DEVICE_NUMBER        = OTX_ATTR_END + 6,  // @emem (OTX_ATTRIB_UINT32) Read only. Device number of the PCI board (PCI boards)
  OTX_ATTR_BRD_PCI_FUNCTION_NUMBER      = OTX_ATTR_END + 7,  // @emem (OTX_ATTRIB_UINT32) Read only. Function number of the PCI board (PCI boards)
  OTX_ATTR_BRD_USER_STRING              = OTX_ATTR_END + 8,  // @emem (OTX_ATTRIB_SZ) Read only. User supplied string stored persistently on the board
  OTX_ATTR_BRD_PCMCIA_DONGLE_TYPE       = OTX_ATTR_END + 9,  // @emem (OTX_ATTRIB_SZ) Read/Write. For PCMCIA boards. Product number (HMA) of attached dongle.
                                                             // The driver provides customized transmit pulse masks (E1/T1 span) for each dongle type.
                                                             // <nl> Thor-2-PCMCIA board supports the following dongles:
                                                             // <nl> HMA-1021-1-1.0-P1   (standard dongle, preliminary version)
                                                             // <nl> HMA-1021-1-1.0      (standard dongle, released version)
                                                             // <nl> HMA-1074-1-1.0-P1   (monitor dongle,  preliminary version)
                                                             // <nl> Thor-2-PCMCIA-Plus board supports the following dongles:
                                                             // <nl> HMA-1076-2-1.0-P1   (Generator dongle, for battery powered equipment, preliminary version)
                                                             // <nl> HMA-1079-2-1.0-P1   (Monitor dongle, for battery powered equipment, preliminary version)
                                                             // <nl> HMA-1079-2-1.0      (Monitor dongle, switchable 0dB and 20dB amplification, for battery powered equipment, released version)
  OTX_ATTR_BRD_DPC_MAX_TIMESLICE        = OTX_ATTR_END + 10, // @emem (OTX_ATTRIB_UINT32) Read/Write. Maximum allowed time (in milliseconds) 
                                                             // to spend serving device interrupts. If this time is execeeded the devices generating 
                                                             // interrupts at an abnormal rate will be disabled (to prevent system from hanging)
  OTX_ATTR_BRD_PNP_ID                   = OTX_ATTR_END + 11, // @emem (OTX_ATTRIB_OCTETS) Read only. Wide-character string. 
                                                             // Plug-and-Play Id of this board. 
                                                             // Only applicable for the WDM driver.
  OTX_ATTR_BRD_PCMCIA_AMP_DONGLE_0      = OTX_ATTR_END + 12, // @emem (OTX_ATTRIB_BOOL) Read/Write. Dongle for Li#0. 
                                                             // Only applicable for Thor-2-PCMCIA-Plus, Thor-2-PCMCIA-CST, Thor-2-PCMCIA-EX, and Thor-2-PCMCIA-PRO cards equipped with the HMA-1079-2-1.0 dongle.
                                                             // The T1/E1 signal amplifier is turned on by setting this attribute to OTX_TRUE. This amplifier should
                                                             // only be used in conjunction with <f OtxT1E1SetMonitorMode> to boost a -30dB attenuated signal to a level that
                                                             // can be monitored by the T1/E1 device. If you are monitoring a -20dB signal then this attribute should be set to OTX_FALSE, and <f OtxT1E1SetMonitorMode> should be turned on.
                                                             // This attribute has the same functionality as the <e OtxT1E1AttributesE.OTX_ATTR_T1E1_RX_AMPLIFIER> attribute, although
                                                             // that attribute uses the handle to the T1/E1 device, versus this attribute that uses the handle to the board itself.
  OTX_ATTR_BRD_PCMCIA_AMP_DONGLE_1      = OTX_ATTR_END + 13, // @emem (OTX_ATTRIB_BOOL) Read/Write. Dongle for Li#1. 
                                                             // Only applicable for Thor-2-PCMCIA-Plus, Thor-2-PCMCIA-CST, Thor-2-PCMCIA-EX, and Thor-2-PCMCIA-PRO cards equipped with the HMA-1079-2-1.0 dongle.
                                                             // The T1/E1 signal amplifier is turned on by setting this attribute to OTX_TRUE. This amplifier should
                                                             // only be used in conjunction with <f OtxT1E1SetMonitorMode> to boost a -30dB attenuated signal to a level that
                                                             // can be monitored by the T1/E1 device. If you are monitoring a -20dB signal then this attribute should be set to OTX_FALSE, and <f OtxT1E1SetMonitorMode> should be turned on.
                                                             // This attribute has the same functionality as the <e OtxT1E1AttributesE.OTX_ATTR_T1E1_RX_AMPLIFIER> attribute, although
                                                             // that attribute uses the handle to the T1/E1 device, versus this attribute that uses the handle to the board itself.
  OTX_ATTR_BRD_DEVICE_ID                = OTX_ATTR_END + 14, // @emem (OTX_ATTRIB_UINT32) Read only. The Device ID is the first number of the Product number for the board.
                                                             // E.g. the device number for Thor-2-PCI (HAA-1022-1) is 1022.
  OTX_ATTR_BRD_SUBSYSTEM_ID             = OTX_ATTR_END + 15, // @emem (OTX_ATTRIB_UINT32) Read only. The Subsystem ID is contain the revision of the board in the following 32-bit format:
                                                             // <nl> MMMMMM + NNNN + R + PPPPP
                                                             // <nl> where
                                                             // <nl> MMMMMM: Major revision (6 bits)
                                                             // <nl> NNNN: Minor revision (4 bits)
                                                             // <nl> R: Released/Preliminary (1 bit), 1=R, 0=P
                                                             // <nl> PPPPP: Preliminary step (5 bits)
                                                             // <nl> Example:
                                                             // <nl> A board of revision 1.0 (released) would have the Subsystem ID of 0x0420.
                                                             // <nl> A board of revision 1.1-P1 (preliminary) would have the Subsystem ID of 0x0441.
  OTX_ATTR_BRD_DSP_PORTS_DISABLED       = OTX_ATTR_END + 16, // @emem (OTX_ATTRIB_BOOL) Read/Write. Default = OTX_FALSE. 
                                                             // By setting this attribute to OTX_TRUE, the clocks (Frame Sync and Data)
                                                             // to the serial ports of the DSPs can be disabled. Leaving theses clocks disabled while
                                                             // loading the DSP programs, and then enabling the clocks, will ensure that the all DSPs 
                                                             // in the board are synchronized.
  OTX_ATTR_BRD_LED_OVERRIDE             = OTX_ATTR_END + 17, // @emem (OTX_ATTRIB_BOOL) Read/Write. Only applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_SLEIPNIR_1_PCI>.
                                                             // <nl> Default is OTX_FALSE. Set to OTX_TRUE
                                                             // to override the driver control of the boards LEDs 
                                                             // (see <e OtxBoardDeviceAttributesE.OTX_ATTR_BRD_LED_STATE>)
  OTX_ATTR_BRD_LED_COUNT                = OTX_ATTR_END + 18, // @emem (OTX_ATTRIB_UINT32) Read only. Only applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_SLEIPNIR_1_PCI>.
                                                             // <nl> Count of Number of LEDS. 
  OTX_ATTR_BRD_LED_STATE                = OTX_ATTR_END + 19, // @emem (OTX_ATTRIB_UINT32) Read/Write. State of LED (On, Off, blink or steady, Color, etc).
                                                             // <nl> The following bit mapping of the value for this attribute applies to the <e OtxPhysicalDeviceTypeE.OTX_DEVICE_SLEIPNIR_1_PCI> board:
                                                             // <nl> Bit 0-15: led state 
                                                             // <nl>  0x0 = Off            ,
                                                             // <nl>  0x1 = ConstantRed    ,
                                                             // <nl>  0x2 = ConstantGreen  ,
                                                             // <nl>  0x3 = ConstantYellow ,
                                                             // <nl>  0x5 = BlinkRed       ,
                                                             // <nl>  0x6 = BlinkGreen     ,
                                                             // <nl>  0x7 = BlinkYellow     
                                                             // <nl> Bit 16-31: led number
                                                             // <nl>  0x0 - AUX
                                                             // <nl>  0x1 - FRM ERR
                                                             // <nl>  0x2 - ALARM
                                                             // <nl>  0x3 - LOS/ACT
  OTX_ATTR_BRD_DSP_SOURCED              = OTX_ATTR_END + 20, // @emem (OTX_ATTRIB_UINT32) Read/Write. Only applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_SLEIPNIR_1_PCI> and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_HUGIN_2_PC104>.
                                                             // <nl> Defines the data source for the DSP device. Acceptable values are <e OtxBrdDevSourcedCodesE.OTX_BRD_DSP_SOURCED_FALC> and
                                                             // <e OtxBrdDevSourcedCodesE.OTX_BRD_DSP_SOURCED_P2S>.
  OTX_ATTR_BRD_FALC_SOURCED             = OTX_ATTR_END + 21, // @emem (OTX_ATTRIB_UINT32) Read/Write. Applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_SLEIPNIR_1_PCI> and
                                                             // <e OtxPhysicalDeviceTypeE.OTX_DEVICE_THOR_2_EXPRESSCARD>.
                                                             // <nl> Defines the data source for the T1/E1 (Falc) Device. Acceptable values are <e OtxBrdDevSourcedCodesE.OTX_BRD_FALC_SOURCED_P2S> and
                                                             // <e OtxBrdDevSourcedCodesE.OTX_BRD_FALC_SOURCED_DSP>.
  OTX_ATTR_BRD_S2P_SOURCED              = OTX_ATTR_END + 22, // @emem (OTX_ATTRIB_UINT32) Read/Write. Only applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_SLEIPNIR_1_PCI> and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_HUGIN_2_PC104>.
                                                             // <nl> Defines the data source for the Burst (S2P) device. Acceptable values are <e OtxBrdDevSourcedCodesE.OTX_BRD_S2P_SOURCED_DSP> and
                                                             // <e OtxBrdDevSourcedCodesE.OTX_BRD_S2P_SOURCED_FALC>.
  OTX_ATTR_BRD_FREQUENCY_COUNTER        = OTX_ATTR_END + 23, // @emem (OTX_ATTRIB_UINT32) Read only. This attribute is available for certain E1/T1 boards like
                                                             // Thor-8-PCI-Plus and Gimle-16-PCI-Plus. The readable attribute contains
                                                             // a counter value that can be used to calculate the frequency of the current clock source (set by <f OtxBrdSetClocks>).
                                                             // This attribute returns the 1 second count of the clock source. For E1, the line frequency is 
                                                             // the register value + 1 divided by 8. For T1, the line frequency is the register value +1 
                                                             // times 193 divided by 2048
  OTX_ATTR_BRD_RESET_ON_OPEN            = OTX_ATTR_END + 24, // @emem (OTX_ATTRIB_BOOL) Read/Write. Perform a Reset when the device is opened.
                                                             // The default is OTX_TRUE.
                                                             // If this attribute is OTX_FALSE, the configuration of the board is taken as-is, and the board is not configured.
                                                             // This attribute must be set immediately after the physical board device is opened to have any affect.
                                                             // This attribute setting remains through the lifetime of the board being loaded by the operating system.
  OTX_ATTR_BRD_WATCHDOG_TIMER_ENABLED   = OTX_ATTR_END + 25, // @emem (OTX_ATTRIB_BOOL) Read/Write. Only applicable for 
                                                             // <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI> 
                                                             // and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI_PLUS>.
                                                             // <nl> The default is OTX_FALSE.
                                                             // <nl> If this attribute is OTX_TRUE, the Watchdog Timer for the 
                                                             // Fail-over relays is running. If the Watchdog Timer times out, then 
                                                             // this attribute will automatically be set to OTX_FALSE by the driver (and
                                                             // the Fail-over relays will switch to the pass-through configuration).
                                                             // In that situation the Watchdog timer can be enabled again by setting this 
                                                             // attribute to OTX_TRUE.
                                                             // <nl> Please also see <e OtxBoardDeviceAttributesE.OTX_ATTR_BRD_WATCHDOG_TIMER_RESET>.
  OTX_ATTR_BRD_WATCHDOG_TIMER_RESET     = OTX_ATTR_END + 26, // @emem (OTX_ATTRIB_BOOL) Write only. 
                                                             // Only applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI> 
                                                             // and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI_PLUS>.
                                                             // <nl> The Watchdog Timer on the board will reset its counter to its
                                                             // starting value (reinitalize) when this attribute is set to OTX_TRUE.
                                                             // The Watchdog timer has control over the Fail-over 
                                                             // relays between the FXO and FXS devices. If the Watchdog timer
                                                             // times out, it will force the fail-over relays into the pass-through 
                                                             // configuration (effectively disconnecting the FXS devices). To keep the 
                                                             // Watchdog timer from timing out, this attribute
                                                             // needs be set to OTX_TRUE at a regular interval (more frequently 
                                                             // than every 100 ms).
                                                             // Setting this attribute to OTX_FALSE has no effect.
                                                             // <nl> See also <e OtxBoardDeviceAttributesE.OTX_ATTR_BRD_WATCHDOG_TIMER_ENABLED>.
  OTX_ATTR_BRD_GROUND_START_ENABLED     = OTX_ATTR_END + 27, // @emem (OTX_ATTRIB_BOOL) Read/Write. Only applicable for 
                                                             // <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI> 
                                                             // and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI_PLUS>.
                                                             // <nl> The default is OTX_false.
                                                             // <nl> If this attribute is OTX_TRUE, the Ground Start detection circuit is enabled. 
                                                             // If this attribute is OTX_FALSE, the Ground Start detection circuit is disabled. 
                                                             // <nl> Please also see <e OtxBoardDeviceAttributesE.OTX_ATTR_BRD_GROUND_START_RESET>.
  OTX_ATTR_BRD_GROUND_START_RESET       = OTX_ATTR_END + 28, // @emem (OTX_ATTRIB_BOOL) Read/Write. Only applicable for 
                                                             // <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI> 
                                                             // and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI_PLUS>.
                                                             // <nl> The default is OTX_FALSE.
                                                             // <nl> If this attribute is OTX_TRUE, the Ground Start detection circuit is held in reset. 
                                                             // If this attribute is OTX_FALSE, the Ground Start detection circuit is not in reset, circuit is active. 
                                                             // <nl> Please also see <e OtxBoardDeviceAttributesE.OTX_ATTR_BRD_GROUND_START_ENABLED>.
  OTX_ATTR_BRD_GROUND_START_STATUS      = OTX_ATTR_END + 29, // @emem (OTX_ATTRIB_UINT32) Read/Write. Only applicable for 
                                                             // <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI> 
                                                             // and <e OtxPhysicalDeviceTypeE.OTX_DEVICE_ARNI_6X6_PCI_PLUS>.
                                                             // <nl> Bit 0-5: Tip_Det(0:5) 0=Ground detected on TIP (read only) 
                                                             // <nl> Bit 0-5: GS_ENA(0:5) 1=Enable the channel for Ground Start. This bit should be set 
                                                             // to 0 during loop operation including off hook. (write only)
                                                             // <nl> Bit 6-11: GND_RING(0:5) 1=Ground RING. (write only) 
                                                             // <nl> Please also see <e OtxBoardDeviceAttributesE.OTX_ATTR_BRD_GROUND_START_RESET>.
  OTX_ATTR_BRD_MONITOR_ONLY             = OTX_ATTR_END + 30, // @emem (OTX_ATTRIB_BOOL) Read/Write. Applicable for <e OtxPhysicalDeviceTypeE.OTX_DEVICE_THOR_4_EXPRESSCARD>.
                                                             // <nl> By default the card is configured to perform as a receive only (monitor) card.
                                                             // Setting this attribute value to OTX_FALSE will allow the card to transmit data. 

  OTX_ATTR_BRD_END                      = OTX_ATTR_END + 31
};

typedef enum OtxBoardDeviceAttributesE OtxBoardDeviceAttributesE;


/******************************************************************************
  @enum
    Sourced Attribute Codes (OTX_ATTR_BRD_xxx)
******************************************************************************/
enum OtxBrdDevSourcedCodesE {
  // OTX_ATTR_BRD_DSP_SOURCED
  OTX_BRD_DSP_SOURCED_FALC        = 0x00, // @emem DSP is sourced by the T1/E1 (Falc) device
  OTX_BRD_DSP_SOURCED_P2S         = 0x01, // @emem DSP is sourced by the P2S (DMA/Burst) device
  // OTX_ATTR_BRD_FALC_SOURCED
  OTX_BRD_FALC_SOURCED_P2S        = 0x02, // @emem The T1/E1 device (Falc) is sourced by the P2S (DMA/Burst) device
  OTX_BRD_FALC_SOURCED_DSP        = 0x03, // @emem The T1/E1 device (Falc) is sourced by the DSP device
  // OTX_ATTR_BRD_S2P_SOURCED
  OTX_BRD_S2P_SOURCED_DSP         = 0x04, // @emem S2P (DMA/Burst) is sourced by the DSP device
  OTX_BRD_S2P_SOURCED_FALC        = 0x05, // @emem S2P (DMA/Burst) is sourced by the T1/E1 (Falc) device

  OTX_BRD_END_OF_DEV_SOURCED_CODES
};


/*******************************************************************************
  @enum
    Board Result Codes
*******************************************************************************/
enum OtxBrdResultCodesE {
  OTX_BRD_RES_END                      = OTX_RES_END + 0
};

typedef enum OtxBrdResultCodesE OtxBrdResultCodesE;


/******************************************************************************
  @enum
    Board Event Codes
******************************************************************************/
enum OtxBrdEventCodesE {
  OTX_BRD_EC_AUTO_DISABLED        = 0x00, // @emem Fatal error has occurred. The board is automatically disabled.
  OTX_BRD_EC_INTR_FREQ_TOO_HIGH   = 0x01, // @emem Interrupt frequency is too high. Data loss is imminent.
  OTX_BRD_EC_INVALID_INTERRUPT    = 0x02, // @emem Invalid interrupt has occurred. Interrupt ignored.
  OTX_BRD_EC_GROUND_START         = 0x03, // @emem Ground Start circuit interrupt

  OTX_BRD_END_OF_EVENT_CODES
};

typedef enum OtxBrdEventCodesE OtxBrdEventCodesE;


/******************************************************************************
  @enum 
    TSS Attributes
******************************************************************************/
enum OtxTssDeviceAttributesE {
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_A  = OTX_ATTR_END + 0, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d0-d3. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_B  = OTX_ATTR_END + 1, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d4-d7. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_C  = OTX_ATTR_END + 2, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d8-d11. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_D  = OTX_ATTR_END + 3, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d12-d15. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_E  = OTX_ATTR_END + 4, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d16-d19. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_F  = OTX_ATTR_END + 5, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d20-d23. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_G  = OTX_ATTR_END + 6, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d24-d27. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.
  OTX_ATTR_TSS_CTBUS_RATE_STREAM_GROUP_H  = OTX_ATTR_END + 7, // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                              // Operating bit rate (in kbps) for CT Bus highway d28-d31. Valid values are 2048 (default), 4096, and 8192.
                                                              // Note: If this attribute is modified, it must be modified before any pipe connections are made.

  OTX_ATTR_TSS_END                       = OTX_ATTR_END + 8
};

typedef enum OtxTssDeviceAttributesE OtxTssDeviceAttributesE;


/******************************************************************************
  @enum
    Time-Space Switch (TSS) Event Codes
******************************************************************************/
enum OtxTssEventCodesE {
  OTX_TSS_EC_CLKERR_A             = 0x00, // @emem C8A or Frame A Clock failed
  OTX_TSS_EC_CLKERR_B             = 0x01, // @emem C8B or Frame B Clock failed
  OTX_TSS_EC_CLKERR_FR_COMP       = 0x02, // @emem FR_COMPn Clock failed
  OTX_TSS_EC_CLKERR_C16           = 0x03, // @emem C16+ C16- Clock failed
  OTX_TSS_EC_CLKERR_C4_C2         = 0x04, // @emem C4 or C2 Clock failed
  OTX_TSS_EC_CLKERR_SCLKX2        = 0x05, // @emem SCLKX2 Clock failed
  OTX_TSS_EC_CLKERR_SCLK          = 0x06, // @emem SCLK Clock failed
  OTX_TSS_EC_CLKERR_NETREF        = 0x07, // @emem NETREF Clock failed
  OTX_TSS_EC_SYSERR_NM_CAM_E      = 0x08, // @emem Even CAM Overflow Error (No Match)
  OTX_TSS_EC_SYSERR_NM_CAM_O      = 0x09, // @emem Odd CAM Overflow Error (No Match)
  OTX_TSS_EC_SYSERR_NM_CAM_L      = 0x0a, // @emem Local CAM Overflow Error (No Match)
  OTX_TSS_EC_SYSERR_CAM_E         = 0x0b, // @emem Even CAM Overflow Error
  OTX_TSS_EC_SYSERR_CAM_O         = 0x0c, // @emem Odd CAM Overflow Error
  OTX_TSS_EC_SYSERR_CAM_L         = 0x0d, // @emem Local CAM Overflow Error
  OTX_TSS_EC_SYSERR_HBUS          = 0x0e, // @emem H-BUS (CT Bus) Data Memory Access Error
  OTX_TSS_EC_SYSERR_FALLBACK      = 0x0f, // @emem Fallback Enable Indicator
  OTX_TSS_EC_CLKERR_APLL1         = 0x10, // @emem APLL1 Reference error
  OTX_TSS_EC_CLKERR_DPLL2         = 0x11, // @emem DPLL2 Sync error
  OTX_TSS_EC_CLKERR_DPLL1         = 0x12, // @emem DPLL1 Sync error

  OTX_TSS_END_OF_EVENT_CODES
};

typedef enum OtxTssEventCodesE OtxTssEventCodesE;


/******************************************************************************
  @enum 
    Board Clock Source. The highways on the OTX boards are all synchronized to 
    one clock. This type (used as parameter to <f OtxBrdSetClocks>) specified 
    the source of this clock.
******************************************************************************/
enum OtxBrdClockSourceE {
  OTX_CLOCK_SOURCE_INTERNAL        = 0x00,   // @emem Board Clock Source Internal Oscillator.
                                             // The board operates as a clock master. The clock
                                             // source is the internal oscillator populated on 
                                             // the OTX board. 
                                             // This mode can drive clocks on the H.100 bus (please 
                                             // refer to <t OtxBrdClockModeE>).

  OTX_CLOCK_SOURCE_CT_NETREF       = 0x01,   // @emem Board Clock Source CT_NETREF
                                             // The board operates as a clock slave, and slaves
                                             // to the CT_NETREF clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_A_CLOCKS        = 0x02,   // @emem Board Clock Source A Clocks (C8A & FRAMEA); 
                                             // MC-1 (inverted 4.096 MHz on C8A)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8A & FRAMEA clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_A_CLOCKS_ETCF   = 0x03,   // @emem Board Clock Source A Clocks (C8A & FRAMEA); 
                                             // ETCF (noninverted 8.192 MHz on C8A)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8A & FRAMEA clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_B_CLOCKS        = 0x04,   // @emem Board Clock Source B Clocks (C8B & FRAMEB); 
                                             // MC-1 (inverted 4.096 MHz on C8B)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8B & FRAMEB clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_B_CLOCKS_ETCF   = 0x05,   // @emem Board Clock Source B Clocks (C8B & FRAMEB); 
                                             // ETCF (noninverted 8.192 MHz on C8B)
                                             // The board operates as a clock slave, and slaves
                                             // to the C8B & FRAMEB clocks provided on the H.100 bus.

  OTX_CLOCK_SOURCE_MVIP            = 0x06,   // @emem Board Clock Source MVIP
                                             // The board operates as a clock slave, and slaves
                                             // to the /C4 clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_HMVIP           = 0x07,   // @emem Board Clock Source H-MVIP
                                             // The board operates as a clock slave, and slaves
                                             // to the /C16 clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_SC_BUS_2_MHZ    = 0x08,   // @emem Board Clock Source SC-Bus 2 Mhz
                                             // The board operates as a clock slave, and slaves
                                             // to the SCLKX2# clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_SC_BUS_4_8_MHZ  = 0x09,   // @emem Board Clock Source SC-Bus 4 or 8 Mhz
                                             // The board operates as a clock slave, and slaves
                                             // to the SCLK clock provided on the H.100 bus.

  OTX_CLOCK_SOURCE_LOCAL_0         = 0x0A,   // @emem Board Clock Source Local Reference 0. 
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 0.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_1         = 0x0B,   // @emem Board Clock Source Local Reference 1.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 1.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_2         = 0x0C,   // @emem Board Clock Source Local Reference 2.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 2.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_3         = 0x0D,   // @emem Board Clock Source Local Reference 3.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 3.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_4         = 0x0E,   // @emem Board Clock Source Local Reference 4.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 4.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_5         = 0x0F,   // @emem Board Clock Source Local Reference 5.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 5.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_6         = 0x10,   // @emem Board Clock Source Local Reference 6.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 6.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_7         = 0x11,   // @emem Board Clock Source Local Reference 7.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 7.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_8         = 0x12,   // @emem Board Clock Source Local Reference 8.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 8.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_9         = 0x13,   // @emem Board Clock Source Local Reference 9.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 9.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_10        = 0x14,   // @emem Board Clock Source Local Reference 10.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 10.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_11        = 0x15,   // @emem Board Clock Source Local Reference 11.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 11.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_12        = 0x16,   // @emem Board Clock Source Local Reference 12.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 12.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_13        = 0x17,   // @emem Board Clock Source Local Reference 13.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 13.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_14        = 0x18,   // @emem Board Clock Source Local Reference 14.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 14.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_LOCAL_15        = 0x19,   // @emem Board Clock Source Local Reference 15.
                                             // The board will recover (slave to) the clock from
                                             // Local Reference 15.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_EXTERNAL        = 0x1A,   // @emem External Clock Source via connector on the OTX board.
                                             // The board will recover (slave to) the clock supplied
                                             // to this connector.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.

  OTX_CLOCK_SOURCE_EXTERNAL_SECONDARY = 0x1B // @emem Secondary External Clock Source via connector on the OTX board.
                                             // The board will recover (slave to) the clock supplied
                                             // to this connector.
                                             // This mode can drive clocks on the H.100 bus 
                                             // (please refer to <t OtxBrdClockModeE>).
                                             // This mode is board specific. For further details please refer 
                                             // to the documentation for each specific OTX board.
};

typedef enum OtxBrdClockSourceE OtxBrdClockSourceE;


/******************************************************************************
  @enum 
    Board Clock Mode. Specifies a connection/disconnection to a H.100 bus, 
    clocks to drive, etc.
******************************************************************************/
enum OtxBrdClockModeE {
  OTX_CLOCK_MODE_NA                = 0,      // @emem Board Clock Mode Not Applicable (used on an OTX boards 
                                             // which are not equipped with an H.100 interface, e.g. Thor-2-PCMCIA)

  OTX_CLOCK_MODE_LOCAL             = 1,      // @emem Board is disconnected (tri-stated) from the H.100 bus

  OTX_CLOCK_MODE_H100              = 2,      // @emem Board is connected to the H.100 bus (MC-1 mode). 
                                             // If this mode is used with any of the bus 
                                             // driving clock sources (see <t OtxBrdClockSourceE>), this mode 
                                             // will drive the C8A, C8B, FRAMEA and FRAMEB H.100 clocks in 
                                             // MC-1 mode (inverted 4.096 MHz).

  OTX_CLOCK_MODE_H100_ETCF         = 3       // @emem Board is connected to the H.100 bus (ETCF mode). 
                                             // If this mode is used with any of the bus 
                                             // driving clock sources (see <t OtxBrdClockSourceE>), this mode 
                                             // will drive the C8A, C8B, FRAMEA and FRAMEB H.100 clocks in 
                                             // ETCF mode (noninverted 8.192 MHz).
};

typedef enum OtxBrdClockModeE OtxBrdClockModeE;



#ifdef __cplusplus
}  // extern "C"
#endif


/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998-2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif    // OTX_BRD_DEF_H
